@@ -1,5 +1,5 @@
 """
- Copyright (c) 2006-2008 Bryan Tong Minh
+ Copyright (c) 2006-2011 Bryan Tong Minh
  
  Permission is hereby granted, free of charge, to any person
  obtaining a copy of this software and associated documentation
@@ -26,7 +26,7 @@
 import sys as _sys
 import os as _os
 _path = _os.path.dirname(__file__)
-_sys.path.append(_os.path.abspath(_path))
+_sys.path.insert(0, _os.path.abspath(_path))
 
 from errors import *
 from client import Site, __ver__
